@@ -62,6 +62,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_certificatemanager
@@ -111,6 +113,10 @@ class HttpsRedirect(
         :param certificate: The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
         :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpsRedirect.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = HttpsRedirectProps(
             target_domain=target_domain,
             zone=zone,
@@ -160,6 +166,12 @@ class HttpsRedirectProps:
                 )
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpsRedirectProps.__init__)
+            check_type(argname="argument target_domain", value=target_domain, expected_type=type_hints["target_domain"])
+            check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
+            check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
+            check_type(argname="argument record_names", value=record_names, expected_type=type_hints["record_names"])
         self._values: typing.Dict[str, typing.Any] = {
             "target_domain": target_domain,
             "zone": zone,
